==> qtjambi-sensors-5.15.14-sources.jar: io/qt/sensors/QTiltSensor.java <==
package io.qt.sensors;

import io.qt.*;


/**
 * <p>Convenience wrapper around QSensor</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qtiltsensor.html">QTiltSensor</a></p>
 */
public class QTiltSensor extends io.qt.sensors.QSensor
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTiltSensor.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QTiltSensor() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qtiltsensor.html#QTiltSensor">QTiltSensor::QTiltSensor(QObject*)</a></p>
     */
    public QTiltSensor(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTiltSensor instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qtiltsensor.html#calibrate">QTiltSensor::calibrate()</a></p>
     */
    public final void calibrate(){
        calibrate_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void calibrate_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qsensor.html#reading-prop">QSensor::reading()const</a></p>
     */
    @QtUninvokable
    public final io.qt.sensors.@Nullable QTiltReading reading(){
        return reading_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.sensors.QTiltReading reading_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QTiltSensor(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QTiltSensor(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QTiltSensor instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-sensors-6.3.1-sources.jar: io/qt/sensors/QTiltSensor.java <==
package io.qt.sensors;


/**
 * <p>Convenience wrapper around QSensor</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qtiltsensor.html">QTiltSensor</a></p>
 */
public class QTiltSensor extends io.qt.sensors.QSensor
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTiltSensor.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTiltSensor(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QTiltSensor() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qtiltsensor.html#QTiltSensor">QTiltSensor::QTiltSensor(QObject*)</a></p>
     */
    public QTiltSensor(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTiltSensor instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qtiltsensor.html#calibrate">QTiltSensor::calibrate()</a></p>
     */
    public final void calibrate(){
        calibrate_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void calibrate_native(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qsensor.html#reading-prop">QSensor::reading()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.sensors.QTiltReading reading(){
        return reading_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.sensors.QTiltReading reading_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QTiltSensor(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QTiltSensor(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QTiltSensor instance, QDeclarativeConstructor constructor);
    
}
